@@ -176,7 +176,7 @@ class SleepPyPatterns(hildon.Program):
                                hildon.BUTTON_ARRANGEMENT_VERTICAL, 
                                _('Statistics'),
                                _('Sleep quality data'))
-        self.button_statistics.connect("clicked", self.test_win)#self.show_stat_window)
+        self.button_statistics.connect("clicked", self.statistics_window)#self.show_stat_window)
         
         image_statistics = gtk.image_new_from_stock(gtk.STOCK_EXECUTE, gtk.ICON_SIZE_BUTTON)
         self.button_statistics.set_image(image_statistics)
@@ -192,7 +192,7 @@ class SleepPyPatterns(hildon.Program):
         
         self.alarm_running = False
     
-    def test_win(self, wiget):
+    def statistics_window(self, wiget):
         # Create a new backing pixmap of the appropriate size
         def configure_event(widget, event):
 
@@ -344,7 +344,9 @@ class SleepPyPatterns(hildon.Program):
                             pass
                         data[i].append(shake)
                         times[i].append(t)
-                        
+            num -= 1
+        num = config.getint('user', 'index')
+        for i in range(plot_max):                        
             deep_sleep_time = 0.0
             fell_asleep = 0.0
             ds = config.getfloat('user', 'deep_sleep')/60.0
@@ -481,9 +483,9 @@ class SleepPyPatterns(hildon.Program):
         event.message = _('Wake Up! Go, get them, Tiger!')
         event.alarm_time = time.time()
         action_stop, action_snooze = event.add_actions(2)
-        action_stop.label = config.get(self.lang, 'stop')
+        action_stop.label = _('stop')
         action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
-        action_snooze.label = config.get(self.lang, 'snooze')
+        action_snooze.label = _('snooze')
         action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
         cookie = alarm.add_event(event)
         return cookie
@@ -571,7 +573,7 @@ class SleepPyPatterns(hildon.Program):
     def set_alarm_up(self):
         self.add_two_button_alarm()
         self.alarm_running = False
-        self.button_alarm.set_value(config.get(self.lang, 'button_alarm'))    
+        self.button_alarm.set_value(_('Click here to start gethering statistics'))    
 
             
 def timed(t):
